//**************************************************************************************************
//*  FRIDA: fast reliable interactive data analysis
//*  (C) Joachim Wuttke 1990-, v2(C++) 2001-
//*  http://apps.jcns.fz-juelich.de/frida
//**************************************************************************************************

//! \file  variables.cpp
//! \brief Implements class SVariRegistry.

#include <algorithm>

#include "variables.hpp"
#include "defs.hpp"
#include "obj.hpp"
#include "ptr.hpp"


PObj SVariRegistry::find(const string& key) const
{
    auto pos = Map.find(key);
    return pos == Map.end() ? nullptr : pos->second;
}

PObj SVariRegistry::find_or_fail(const string& key) const
{
    PObj ret = find(key);
    if (!ret)
        throw "Cannot find variable '" + key + "'";
    return ret;
}


void SVariRegistry::display_all() const
{
    vector<string> keys;
    for (const auto& it: Map)
        keys.push_back(it.first);
    sort(keys.begin(), keys.end());
    for (const string& key: keys)
        cout << "  " << key << " = " << Map.at(key)->to_s() << "\n";
}

void SVariRegistry::register_scalar(const string& key, PObj val) { Map[key] = val; }

//! Undefines a key (removes entry from registry); returns true unless the key wasn't defined.

bool SVariRegistry::undef(const string& key)
{
    auto pos = Map.find(key);
    if (pos == Map.end())
        return false; // failure
    Map.erase(pos);
    return true;
}

std::map<const string, string> SVariRegistry::to_sMap() const
{
    std::map<const string, string> ret;
    for (const auto& it: Map) {
        ret[it.first] = it.second->to_s();
    }
    return ret;
}
